@@ -7,6 +7,7 @@ This package includes:
 - `map_timezone_to_region`: Function to map detailed timezone names to broader, 
   more general region names (e.g., 'Eastern', 'Central').
 - `get_lat_long`: Function to retrieve the latitude and longitude for a given ZIP code.
+- 'get_timezone_for_many_zips' and 'get_lat_long_for_many_zips' for multiple zip codes
 
 Example usage:
 from ziptimezone import get_timezone_by_zip, get_lat_long_for_zip
@@ -18,8 +19,17 @@ timezone = get_timezone_by_zip('85260')
 latitude, longitude = get_lat_long_for_zip('02138')
 """
 
-from .core import get_timezone_by_zip
-from .mappings import map_timezone_to_region
-from .geocode import get_lat_long_for_zip
+from .core import get_timezone_by_zip, get_lat_long_for_zip
+from .data_manager import refresh_data_if_needed
+from .batch_processor import get_timezone_for_many_zips, get_lat_long_for_many_zips
 
-__all__ = ['get_timezone_by_zip', 'map_timezone_to_region', 'get_lat_long_for_zip']
+##from .mappings import map_timezone_to_region
+# from .geocode import get_lat_long_for_zip
+
+__all__ = [
+    "get_timezone_by_zip",
+    "refresh_data_if_needed",
+    "get_lat_long_for_zip",
+    "get_timezone_for_many_zips",
+    "get_lat_long_for_many_zips",
+]
